@@ -9,14 +9,15 @@
 
 extern "C" {
 
-	SEXP dWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+	SEXP dWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
 
 		/* define input variables */
 		double *t = REAL(re1);
 		double *a = REAL(re2);
 		double *v = REAL(re3);
 		double *w = REAL(re4);
-		double eps = REAL(re5)[0];
+		double *sv = REAL(re5);
+		double eps = REAL(re6)[0];
 
 		int *resp = INTEGER(in1);
 		int K = INTEGER(in2)[0];
@@ -41,7 +42,7 @@ extern "C" {
 		double *Rlogpdf = REAL(logpdf);
 
 		/* calculate the derivatives */
-		PDF(t, a, v, w, eps, resp, K, N, epsFLAG, Rpdf, Rlogpdf, NThreads);
+		PDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rpdf, Rlogpdf, NThreads);
 
 
 		/* set elements of list out */
@@ -71,14 +72,15 @@ extern "C" {
 
 extern "C" {
 
-	SEXP dtdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+	SEXP dtdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
 
 		/* define input variables */
 		double *t = REAL(re1);
 		double *a = REAL(re2);
 		double *v = REAL(re3);
 		double *w = REAL(re4);
-		double eps = REAL(re5)[0];
+		double *sv = REAL(re5);
+		double eps = REAL(re6)[0];
 
 		int *resp = INTEGER(in1);
 		int K = INTEGER(in2)[0];
@@ -101,7 +103,7 @@ extern "C" {
 
 
 		/* calculate the derivatives */
-		dtPDF(t, a, v, w, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
+		dtPDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
 
 
 		/* set elements of list out */
@@ -129,14 +131,15 @@ extern "C" {
 
 extern "C" {
 
-	SEXP dadWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+	SEXP dadWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
 
 		/* define input variables */
 		double *t = REAL(re1);
 		double *a = REAL(re2);
 		double *v = REAL(re3);
 		double *w = REAL(re4);
-		double eps = REAL(re5)[0];
+		double *sv = REAL(re5);
+		double eps = REAL(re6)[0];
 
 		int *resp = INTEGER(in1);
 		int K = INTEGER(in2)[0];
@@ -159,7 +162,7 @@ extern "C" {
 
 
 		/* calculate the derivatives */
-		daPDF(t, a, v, w, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
+		daPDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
 
 
 		/* set elements of list out */
@@ -187,14 +190,15 @@ extern "C" {
 
 extern "C" {
 
-	SEXP dvdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+	SEXP dvdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
 
 		/* define input variables */
 		double *t = REAL(re1);
 		double *a = REAL(re2);
 		double *v = REAL(re3);
 		double *w = REAL(re4);
-		double eps = REAL(re5)[0];
+		double *sv = REAL(re5);
+		double eps = REAL(re6)[0];
 
 		int *resp = INTEGER(in1);
 		int K = INTEGER(in2)[0];
@@ -217,7 +221,7 @@ extern "C" {
 
 
 		/* calculate the derivatives */
-		dvPDF(t, a, v, w, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
+		dvPDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
 
 
 		/* set elements of list out */
@@ -245,14 +249,15 @@ extern "C" {
 
 extern "C" {
 
-	SEXP dwdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+	SEXP dwdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
 
 		/* define input variables */
 		double *t = REAL(re1);
 		double *a = REAL(re2);
 		double *v = REAL(re3);
 		double *w = REAL(re4);
-		double eps = REAL(re5)[0];
+		double *sv = REAL(re5);
+		double eps = REAL(re6)[0];
 
 		int *resp = INTEGER(in1);
 		int K = INTEGER(in2)[0];
@@ -275,7 +280,7 @@ extern "C" {
 
 
 		/* calculate the derivatives */
-		dwPDF(t, a, v, w, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
+		dwPDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
 
 
 		/* set elements of list out */
@@ -301,6 +306,64 @@ extern "C" {
 
 
 
+extern "C" {
+  
+  SEXP dsvdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+    
+    /* define input variables */
+    double *t = REAL(re1);
+    double *a = REAL(re2);
+    double *v = REAL(re3);
+    double *w = REAL(re4);
+    double *sv = REAL(re5);
+    double eps = REAL(re6)[0];
+    
+    int *resp = INTEGER(in1);
+    int K = INTEGER(in2)[0];
+    int N = INTEGER(in3)[0];
+    int NThreads = INTEGER(in4)[0];
+    
+    int epsFLAG = INTEGER(bo1)[0];
+    
+    
+    /* declare R objects for output */
+    int outCnt = 0, prtCnt = 0;
+    SEXP deriv = PROTECT(Rf_allocVector(REALSXP, N));
+    outCnt++;
+    SEXP out = PROTECT(Rf_allocVector(VECSXP, outCnt));
+    prtCnt = outCnt + 1;
+    
+    
+    /* declare C++ pointers for R objects */
+    double *Rderiv = REAL(deriv);
+    
+    
+    /* calculate the derivatives */
+    dsvPDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rderiv, NThreads);
+    
+    
+    /* set elements of list out */
+    SET_VECTOR_ELT(out,0,deriv);
+    
+    
+    /* make name vector and set element names */
+    SEXP names = PROTECT(Rf_allocVector(STRSXP, outCnt));
+    prtCnt++;
+    SET_STRING_ELT(names,0,Rf_mkChar("deriv"));
+    
+    Rf_setAttrib(out,R_NamesSymbol,names);
+    
+    
+    /* Unprotect the out and names objects */
+    UNPROTECT(prtCnt);
+    
+    return(out);
+  }
+  
+}
+
+
+
 extern "C" {
 
 	SEXP pWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
@@ -539,14 +602,15 @@ extern "C" {
 
 extern "C" {
 
-	SEXP dxdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
+	SEXP dxdWiener(SEXP re1, SEXP re2, SEXP re3, SEXP re4, SEXP re5, SEXP re6, SEXP in1, SEXP in2, SEXP in3, SEXP in4, SEXP bo1) {
 
 		/* define input variables */
 		double *t = REAL(re1);
 		double *a = REAL(re2);
 		double *v = REAL(re3);
 		double *w = REAL(re4);
-		double eps = REAL(re5)[0];
+		double *sv = REAL(re5);
+		double eps = REAL(re6)[0];
 
 		int *resp = INTEGER(in1);
 		int K = INTEGER(in2)[0];
@@ -575,7 +639,7 @@ extern "C" {
 
 
 		/* calculate the derivatives */
-		dxPDF(t, a, v, w, eps, resp, K, N, epsFLAG, Rda, Rdv, Rdw, NThreads);
+		dxPDF(t, a, v, w, sv, eps, resp, K, N, epsFLAG, Rda, Rdv, Rdw, NThreads);
 
 
 		/* set elements of list out */
